summaryrefslogtreecommitdiffhomepage
path: root/lib/skels/jao-skel-asdf.el
diff options
context:
space:
mode:
authorjao <jao@gnu.org>2022-03-13 00:42:38 +0000
committerjao <jao@gnu.org>2022-03-13 00:42:38 +0000
commit79b00f3c656e09463680785556692cb598935819 (patch)
treea2a37cf0fc796bda5e722046abe07ac178b14f5e /lib/skels/jao-skel-asdf.el
parent747696945a91464e34af86f49d373d1d7a9130c0 (diff)
downloadelibs-79b00f3c656e09463680785556692cb598935819.tar.gz
elibs-79b00f3c656e09463680785556692cb598935819.tar.bz2
skels: provide/require jao-skel-prefixed
Diffstat (limited to 'lib/skels/jao-skel-asdf.el')
-rw-r--r--lib/skels/jao-skel-asdf.el10
1 files changed, 5 insertions, 5 deletions
diff --git a/lib/skels/jao-skel-asdf.el b/lib/skels/jao-skel-asdf.el
index 939eb8d..cb5761e 100644
--- a/lib/skels/jao-skel-asdf.el
+++ b/lib/skels/jao-skel-asdf.el
@@ -1,6 +1,6 @@
;;; asdf-skel.el --- Skels for ASDF system definition files
;; Copyright (C) 2007 Jose Antonio Ortega Ruiz
;; Author: Jose Antonio Ortega Ruiz <jao@gnu.org>
;; Keywords: lisp
@@ -22,7 +22,7 @@
;;; Code:
-(require 'common-skel)
+(require 'jao-skel)
(define-skeleton jao-skel-asdf-file
"ASDF file header"
@@ -48,5 +48,5 @@
(add-to-list 'auto-insert-alist '("\\.asd\\'" . jao-skel-asdf-file))
-(provide 'asdf-skel)
-;;; asdf-skel.el ends here
+(provide 'jao-skel-asdf)
+;;; jao-skel-asdf.el ends here
@@ -1,6 +1,6 @@
-;;; asdf-skel.el --- Skels for ASDF system definition files
+;;; jao-skel-asdf.el --- Skels for ASDF system definition files
-;; Copyright (C) 2007 Jose Antonio Ortega Ruiz
+;; Copyright (C) 2007, 2022 Jose Antonio Ortega Ruiz
;; Author: Jose Antonio Ortega Ruiz <jao@gnu.org>
;; Keywords: lisp